Vantage - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Vantage

The Davis Vantage stations include a variety of models and configurations. The WeeWX driver can communicate with a console or envoy using serial, USB, or TCP/IP interface.

## Configuring with `weectl device`

The Vantage stations can be configured with the utility `weectl device`.

Note

Make sure you stop `weewxd` before running `weectl device`

### `--help`

Invoking `weectl device` with the `--help` option

    weectl device /home/weewx/weewx.conf --help

will produce something like this:

    Using configuration file /home/weewx-user/weewx-data/weewx.conf
    Using driver weewx.drivers.vantage.
    Using Vantage driver version 3.6.2 (weewx.drivers.vantage)
    Usage: weectl device --help
           weectl device --info [config_file]
           weectl device --current [config_file]
           weectl device --clear-memory [config_file] [-y]
           weectl device --set-interval=MINUTES [config_file] [-y]
           weectl device --set-latitude=DEGREE [config_file] [-y]
           weectl device --set-longitude=DEGREE [config_file] [-y]
           weectl device --set-altitude=FEET [config_file] [-y]
           weectl device --set-barometer=inHg [config_file] [-y]
           weectl device --set-wind-cup=CODE [config_file] [-y]
           weectl device --set-bucket=CODE [config_file] [-y]
           weectl device --set-rain-year-start=MM [config_file] [-y]
           weectl device --set-offset=VARIABLE,OFFSET [config_file] [-y]
           weectl device --set-transmitter-type=CHANNEL,TYPE,TEMP,HUM,REPEATER_ID [config_file] [-y]
           weectl device --set-retransmit=[OFF|ON|ON,CHANNEL] [config_file] [-y]
           weectl device --set-temperature-logging=[LAST|AVERAGE] [config_file] [-y]
           weectl device --set-time [config_file] [-y]
           weectl device --set-dst=[AUTO|ON|OFF] [config_file] [-y]
           weectl device --set-tz-code=TZCODE [config_file] [-y]
           weectl device --set-tz-offset=HHMM [config_file] [-y]
           weectl device --set-lamp=[ON|OFF] [config_file]
           weectl device --dump [--batch-size=BATCH_SIZE] [config_file] [-y]
           weectl device --logger-summary=FILE [config_file] [-y]
           weectl device [--start | --stop] [config_file]

    Configures the Davis Vantage weather station.

    Options:
      -h, --help            show this help message and exit
      --debug               display diagnostic information while running
      -y                    answer yes to every prompt
      --info                To print configuration, reception, and barometer
                            calibration information about your weather station.
      --current             To print current LOOP information.
      --clear-memory        To clear the memory of your weather station.
      --set-interval=MINUTES
                            Sets the archive interval to the specified number of
                            minutes. Valid values are 1, 5, 10, 15, 30, 60, or
                            120.
      --set-latitude=DEGREE
                            Sets the latitude of the station to the specified
                            number of tenth degree.
      --set-longitude=DEGREE
                            Sets the longitude of the station to the specified
                            number of tenth degree.
      --set-altitude=FEET   Sets the altitude of the station to the specified
                            number of feet.
      --set-barometer=inHg  Sets the barometer reading of the station to a known
                            correct value in inches of mercury. Specify 0 (zero)
                            to have the console pick a sensible value.
      --set-wind-cup=CODE   Set the type of wind cup. Specify '0' for small size;
                            '1' for large size
      --set-bucket=CODE     Set the type of rain bucket. Specify '0' for 0.01
                            inches; '1' for 0.2 mm; '2' for 0.1 mm
      --set-rain-year-start=MM
                            Set the rain year start (1=Jan, 2=Feb, etc.).
      --set-offset=VARIABLE,OFFSET
                            Set the onboard offset for VARIABLE inTemp, outTemp,
                            extraTemp[1-7], inHumid, outHumid, extraHumid[1-7],
                            soilTemp[1-4], leafTemp[1-4], windDir) to OFFSET
                            (Fahrenheit, %, degrees)
      --set-transmitter-type=CHANNEL,TYPE,TEMP,HUM,REPEATER_ID
                            Set the transmitter type for CHANNEL (1-8), TYPE
                            (0=iss, 1=temp, 2=hum, 3=temp_hum, 4=wind, 5=rain,
                            6=leaf, 7=soil, 8=leaf_soil, 9=sensorlink, 10=none),
                            as extra TEMP station and extra HUM station (both 1-7,
                            if applicable), REPEATER_ID (A-H, or 0=OFF)
      --set-retransmit=OFF|ON|ON,CHANNEL
                            Turn ISS retransmit 'ON' or 'OFF', using optional CHANNEL.
      --set-temperature-logging=LAST|AVERAGE
                            Set console temperature logging to either 'LAST' or
                            'AVERAGE'.
      --set-time            Set the onboard clock to the current time.
      --set-dst=AUTO|ON|OFF
                            Set DST to 'ON', 'OFF', or 'AUTO'
      --set-tz-code=TZCODE  Set timezone code to TZCODE. See your Vantage manual
                            for valid codes.
      --set-tz-offset=HHMM  Set timezone offset to HHMM. E.g. '-0800' for U.S.
                            Pacific Time.
      --set-lamp=ON|OFF     Turn the console lamp 'ON' or 'OFF'.
      --dump                Dump all data to the archive. NB: This may result in
                            many duplicate primary key errors.
      --batch-size=BATCH_SIZE
                            Use with option --dump. Pages are read off the console
                            in batches of BATCH_SIZE. A BATCH_SIZE of zero means
                            dump all data first, then put it in the database. This
                            can improve performance in high-latency environments,
                            but requires sufficient memory to hold all station
                            data. Default is 1 (one).
      --logger-summary=FILE
                            Save diagnostic summary to FILE (for debugging the
                            logger).
      --start               Start the logger.
      --stop                Stop the logger.

    Be sure to stop weewxd first before using. Mutating actions will request
    confirmation before proceeding.

### `--info`

Use the `--info` option to display the current EEPROM settings:

    weectl device --info

This will result in something like:

    Using configuration file /home/weewx/weewx.conf
    Using driver weewx.drivers.vantage.
    Using Vantage driver version 3.6.2 (weewx.drivers.vantage)
    Querying...
    Davis Vantage EEPROM settings:

        CONSOLE TYPE:                   Vantage Pro2

        CONSOLE FIRMWARE:
          Date:                         Dec 11 2012
          Version:                      3.12

        CONSOLE SETTINGS:
          Archive interval:             300 (seconds)
          Altitude:                     700 (foot)
          Wind cup type:                large
          Rain bucket type:             0.01 inches
          Rain year start:              10
          Onboard time:                 2023-05-01 07:35:25

        CONSOLE DISPLAY UNITS:
          Barometer:                    mbar
          Temperature:                  degree_F
          Rain:                         inch
          Wind:                         mile_per_hour

        CONSOLE STATION INFO:
          Latitude (onboard):           +46.0
          Longitude (onboard):          -121.6
          Use manual or auto DST?       AUTO
          DST setting:                  N/A
          Use GMT offset or zone code?  ZONE_CODE
          Time zone code:               4
          GMT offset:                   N/A
          Temperature logging:          AVERAGE

        TRANSMITTERS:
          Channel   Receive     Retransmit  Repeater  Type
             1      inactive    N           NONE      iss
             2      inactive    N           NONE      (N/A)
             3      active      N           NONE      temp (as extra temperature 1)
             4      active      N           8         temp_hum (as extra temperature 4 and extra humidity 1)
             5      inactive    N           NONE      (N/A)
             6      inactive    Y           NONE      (N/A)
             7      inactive    N           NONE      (N/A)
             8      inactive    N           NONE      (N/A)

        RECEPTION STATS:
          Total packets received:       2895
          Total packets missed:         82
          Number of resynchronizations: 0
          Longest good stretch:         330
          Number of CRC errors:         134

        BAROMETER CALIBRATION DATA:
          Current barometer reading:    29.821 inHg
          Altitude:                     700 feet
          Dew point:                    43 F
          Virtual temperature:          56 F
          Humidity correction factor:   1.7
          Correction ratio:             1.026
          Correction constant:          +0.036 inHg
          Gain:                         0.000
          Offset:                       -47.000

        OFFSETS:
          Wind direction:               +0 deg
          Inside Temperature:           +0.0 F
          Inside Humidity:              +0 %
          Outside Temperature:          +0.0 F
          Outside Humidity:             +0 %
          Extra Temperature 1:          +0.0 F
          Extra Temperature 4:          +0.0 F
          Extra Humidity 1:             +0.0 F

The console version number is available only on consoles with firmware dates after about 2006.

Highlighted values can be modified using the commands below.

### `--current`

This command will print a single LOOP packet.

### `--clear-memory`

This command will clear the logger memory after asking for confirmation.

### `--set-interval=N`

Use this command to change the archive interval of the internal logger. Valid intervals are 1, 5, 10, 15, 30, 60, or 120 minutes. However, if you are ftp'ing lots of files to a server, setting it to one minute may not give enough time to have them all uploaded before the next archive record is due. If this is the case, you should pick a longer archive interval, or trim the number of files you are using.

An archive interval of five minutes works well for the Vantage stations. Because of the large amount of onboard memory they carry, going to a larger interval does not have any real advantages.

Example: change the archive interval to 10 minutes:

    weectl device --set-interval=10

### `--set-altitude=N`

Use this command to set the console's stored altitude. The altitude must be in feet.

Example: change the altitude to 700 feet:

    weectl device --set-altitude=700

### `--set-barometer=N`

Use this command to calibrate the barometer in your Vantage weather station. To use it, you must have a known correct barometer reading for your altitude. In practice, you will either have to move your console to a known-correct station (perhaps a nearby airport) and perform the calibration there, or reduce the barometer reading to your altitude. Otherwise, specify the value zero and the station will pick a sensible value.

The barometer value must be in inches of Mercury.

### `--set-bucket`

Normally, this is set by Davis, but if you have replaced your bucket with a different kind, you might want to reconfigure. For example, to change to a 0.1 mm bucket (bucket code `2`), use the following:

    weectl device --set-bucket=2

### `--set-rain-year-start`

The Davis Vantage series allows the start of the rain year to be something other than 1 January.

For example, to set it to 1 October:

    weectl device --set-rain-year-start=10

### `--set-offset`

The Davis instruments can correct sensor errors by adding an offset to their emitted values. This is particularly useful for Southern Hemisphere users. Davis fits the wind vane to the Integrated Sensor Suite (ISS) in a position optimized for Northern Hemisphere users, who face the solar panel to the south. Users south of the equator must orient the ISS's solar panel to the north to get maximal insolation, resulting in a 180° error in the wind direction. The solution is to add a 180° offset correction. You can do this with the following command:

    weectl device --set-offset=windDir,180

### `--set-transmitter-type`

If you have additional sensors and/or repeaters for your Vantage station, you can configure them using your console. However, if you have a Davis Weather Envoy, it will not have a console! As an alternative, `weectl device` can do this using the command `--set-transmitter-type`.

For example, to add an extra temperature sensor to channel 3 and no repeater is used, do the following:

    weectl device --set-transmitter-type=3,1,2

This says to turn on channel 3, set its type to 1 ("Temperature only"), and it will show up in the database as `extraTemp2`. No repeater id was specified, so it defaults to "no repeater."

Here's another example, this time for a combined temperature / humidity sensor retransmitted via repeater A:

    weectl device --set-transmitter-type=5,3,2,4,a

This will add the combined sensor to channel 5, set its type to 3 ("Temperature and humidity"), via Repeater A, and it will show up in the database as `extraTemp2` and `extraHumid4`.

The `--help` option will give you the code for each sensor type and repeater id.

If you have to use repeaters with your Vantage Pro2 station, please take a look at Installing Repeater Networks for Vantage Pro2 for how to set them up.

### `--set-retransmit`

Use this command to tell your console whether to act as a retransmitter of ISS data.

Example: Tell your console to retransmit ISS data using the first available channel:

    weectl device --set-retransmit=on

Example: Tell your console to retransmit ISS data on channel 4:

    weectl device --set-retransmit=on,4

Warning

You can use only channels not actively used for reception. The command checks for this and will not accept channel numbers actively used for reception of sensor stations.

Example: Tell your console to turn retransmission 'OFF':

    weectl device --set-retransmit=off

### `--set-dst`

Use the command to tell your console whether daylight savings time is in effect, or to have it set automatically based on the time zone.

### `--set-tz-code`

This command can be used to change the time zone. Consult the Vantage manual for the code that corresponds to your time zone.

For example, to set the time zone code to Central European Time (code 20):

    weectl device --set-tz-code=20

Warning

You can set either the time zone code or the time zone offset, but not both.

### `--set-tz-offset`

If you live in an odd time zone that is perhaps not covered by the "canned" Davis time zones, you can set the offset from UTC using this command.

For example, to set the time zone offset for Newfoundland Standard Time (UTC-03:30), use the following:

    weectl device --set-tz-offset=-0330

Warning

You can set either the time zone code or the time zone offset, but not both.

### `--set-lamp`

Use this command to turn the console lamp on or off.

### `--dump`

Generally, WeeWX downloads only new archive records from the on-board logger in the Vantage. However, occasionally the memory in the Vantage will get corrupted, making this impossible. See the section WeeWX generates HTML pages, but it does not update them in the Wiki. The fix involves clearing the memory but, unfortunately, this means you may lose any data which might have accumulated in the logger memory, but not yet downloaded. By using the `--dump` command before clearing the memory, you might be able to save these data.

Stop WeeWX first, then

    weectl device --dump

This will dump all data archived in the Vantage memory directly to thee database, without regard to whether or not they have been seen before. Because the command dumps all data, it may result in many duplicate primary key errors. These can be ignored.

### `--logger-summary`

This command is useful for debugging the console logger. It will scan the logger memory, recording the timestamp in each page and index slot to the file `FILE`.

Example:

    weectl device --logger-summary=/var/tmp/summary.txt

### `--start`

Use this command to start the logger. There are occasions when an out-of-the-box logger needs this command.

### `--stop`

Use this command to stop the logger. This can be useful when servicing your weather station, and you don't want any bad data to be stored in the logger.

## Station data

The following table shows which data are provided by the station hardware and which are calculated by WeeWX.

Vantage station data
Database Field | Observation | Loop | Archive
barometer | barometer | H | H
pressure |  | S | S
altimeter |  | S | S
inTemp | inTemp | H | H
outTemp | outTemp | H | H
inHumidity | inHumidity | H | H
outHumidity | outHumidity | H | H
windSpeed | windSpeed | H | H
windDir | windDir | H | H
windGust | windGust | H | H
windGustDir | windGustDir | H | H
rain | rain | D | H
| monthRain | H | H
rainRate | rainRate | H | H
dewpoint |  | S | S
windchill |  | S | S
heatindex |  | S | S
radiation | radiation | H | H
UV | UV | H | H
extraTemp1 | extraTemp1 | H | H
extraTemp2 | extraTemp2 | H | H
extraTemp3 | extraTemp3 | H | H
extraTemp4 | extraTemp4 | H |
extraTemp5 | extraTemp5 | H |
extraTemp6 | extraTemp6 | H |
extraTemp7 | extraTemp7 | H |
soilTemp1 | soilTemp1 | H | H
soilTemp2 | soilTemp2 | H | H
soilTemp3 | soilTemp3 | H | H
soilTemp4 | soilTemp4 | H | H
leafTemp1 | leafTemp1 | H | H
leafTemp2 | leafTemp2 | H | H
leafTemp3 | leafTemp3 | H | H
leafTemp4 | leafTemp4 | H | H
extraHumid1 | extraHumid1 | H | H
extraHumid2 | extraHumid2 | H | H
extraHumid3 | extraHumid3 | H |
extraHumid4 | extraHumid4 | H |
extraHumid5 | extraHumid5 | H |
extraHumid6 | extraHumid6 | H |
extraHumid7 | extraHumid7 | H |
soilMoist1 | soilMoist1 | H | H
soilMoist2 | soilMoist2 | H | H
soilMoist3 | soilMoist3 | H | H
soilMoist4 | soilMoist4 | H | H
leafWet1 | leafWet1 | H | H
leafWet2 | leafWet2 | H | H
leafWet3 | leafWet3 | H | H
leafWet4 | leafWet4 | H | H
txBatteryStatus | txBatteryStatus | H | H
consBatteryVoltage | consBatteryVoltage | H | H
| wind_samples |  | H

H indicates data provided by Hardware
D indicates data calculated by the Driver
S indicates data calculated by the StdWXCalculate Service